pub struct Committee {
pub epoch: EpochId,
pub voting_rights: Vec<(AuthorityName, StakeUnit)>,
/* private fields */
}Fields
epoch: EpochIdvoting_rights: Vec<(AuthorityName, StakeUnit)>Implementations
Sourceimpl Committee
impl Committee
pub fn new( epoch: EpochId, voting_rights: BTreeMap<AuthorityName, StakeUnit>, ) -> Self
Sourcepub fn from_committee_members(
epoch: EpochId,
members: &[ValidatorCommitteeMember],
) -> Self
pub fn from_committee_members( epoch: EpochId, members: &[ValidatorCommitteeMember], ) -> Self
Build a committee for epoch from a [ValidatorCommitteeMember]
list.
Sourcepub fn committee_members(&self) -> Vec<ValidatorCommitteeMember>
pub fn committee_members(&self) -> Vec<ValidatorCommitteeMember>
The committee’s voting rights expressed as a
[ValidatorCommitteeMember] list used by EndOfEpochData.
Sourcepub fn new_for_testing_with_normalized_voting_power(
epoch: EpochId,
voting_weights: BTreeMap<AuthorityName, StakeUnit>,
) -> Self
pub fn new_for_testing_with_normalized_voting_power( epoch: EpochId, voting_weights: BTreeMap<AuthorityName, StakeUnit>, ) -> Self
Normalize the given weights to TOTAL_VOTING_POWER and create the committee. Used for testing only: a production system is using the voting weights of the Iota System object.
pub fn load_inner( voting_rights: &[(AuthorityName, StakeUnit)], ) -> (HashMap<AuthorityName, AuthorityPublicKey>, HashMap<AuthorityName, usize>)
pub fn epoch(&self) -> EpochId
pub fn public_key( &self, authority: &AuthorityName, ) -> IotaResult<&AuthorityPublicKey>
Sourcepub fn sample(&self) -> &AuthorityName
pub fn sample(&self) -> &AuthorityName
Samples authorities by weight
pub fn choose_multiple_weighted_iter( &self, count: usize, ) -> impl Iterator<Item = &AuthorityName>
pub fn total_votes(&self) -> StakeUnit
pub fn quorum_threshold(&self) -> StakeUnit
pub fn validity_threshold(&self) -> StakeUnit
pub fn threshold<const STRENGTH: bool>(&self) -> StakeUnit
Sourcepub fn effective_threshold(&self, buffer_stake_bps: u64) -> StakeUnit
pub fn effective_threshold(&self, buffer_stake_bps: u64) -> StakeUnit
Calculates the effective threshold for protocol version selection. This is the quorum threshold plus a buffer stake based on the given basis points.
The buffer is calculated as: f * buffer_stake_bps / 10000, rounded up where f = total_votes - quorum_threshold
buffer_stake_bps is clamped to a maximum of 10000.
pub fn num_members(&self) -> usize
pub fn members(&self) -> impl Iterator<Item = &(AuthorityName, StakeUnit)>
pub fn names(&self) -> impl Iterator<Item = &AuthorityName>
pub fn stakes(&self) -> impl Iterator<Item = StakeUnit> + '_
Sourcepub fn stake_by_index(&self, index: u32) -> Option<StakeUnit>
pub fn stake_by_index(&self, index: u32) -> Option<StakeUnit>
Returns the stake of the authority at the given index, or None if out
of bounds.
Sourcepub fn shuffle_by_stake_from_tx_digest(
&self,
tx_digest: &TransactionDigest,
) -> Vec<AuthorityName> ⓘ
pub fn shuffle_by_stake_from_tx_digest( &self, tx_digest: &TransactionDigest, ) -> Vec<AuthorityName> ⓘ
Derive a seed deterministically from the transaction digest and shuffle the validators.
pub fn new_simple_test_committee_of_size( size: usize, ) -> (Self, Vec<AuthorityKeyPair>)
Sourcepub fn new_simple_test_committee() -> (Self, Vec<AuthorityKeyPair>)
pub fn new_simple_test_committee() -> (Self, Vec<AuthorityKeyPair>)
Generate a simple committee with 4 validators each with equal voting stake of 1.